pygeodesy.albers.AlbersEqualAreaCylindrical

Package pygeodesy :: Module albers :: Class AlbersEqualAreaCylindrical |
[frames] | no frames]

# Class AlbersEqualAreaCylindrical

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
             _AlbersBase --+
                           |
                          AlbersEqualAreaCylindrical

An AlbersEqualArea projection at `lat=0` and `k0=1` degenerating to the cylindrical-equal-area projection.

Instance Methods
__init__(self, lat=0.0, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, **name) New AlbersEqualAreaCylindrical projection. |
Inherited from `_AlbersBase`: `forward`, `rescale0`, `reverse`, `toRepr`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_AlbersBase`: `a`, `datum`, `ellipsoid`, `equatoradius`, `f`, `flattening`, `isPolar`, `ispolar`, `lat0`, `lat1`, `lat2`, `majoradius`, `scale0` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lat=0.0, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, **name) (Constructor) |
New AlbersEqualAreaCylindrical projection. Arguments: `lat` - Standard parallel (`0 degrees` fixed). `datum` - Optional datum or ellipsoid (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `name` - Optional `name=NN` for the projection (`str`). Overrides: object.__init__